@@ -6,7 +6,7 @@
 * @package language
 * @version $Id$
 * @copyright (c) 2005 phpBB Group, (c) 2005 phpBB.fr
-* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License 2.0
+* @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
 */
 
@@ -224,7 +224,7 @@ $lang = array_merge($lang, array(
 	'DISABLE'					=> 'Désactiver',
 	'DOWNLOAD'					=> 'Télécharger',
 	'DOWNLOAD_AS'				=> 'Télécharger sous ',
-	'DOWNLOAD_STORE'			=> 'Télécharger ou stocker le fichier ',
+	'DOWNLOAD_STORE'			=> 'Télécharger ou stocker le fichier',
 	'DOWNLOAD_STORE_EXPLAIN'	=> 'Vous pouvez télécharger directement le fichier ou le sauvegarder dans votre répertoire <samp>store/</samp>.',
 
 	'EDIT'					=> 'Éditer',
@@ -237,7 +237,7 @@ $lang = array_merge($lang, array(
 	'GLOBAL_MASK'			=> 'Masque de permission globale',
 
 	'INSTALL'				=> 'Installer',
-	'IP'					=> 'Adresse IP de l’utilisateur',
+	'IP'					=> 'Adresse IP de l’utilisateur ',
 	'IP_HOSTNAME'			=> 'Adresse(s) IP ou nom(s) d’hôte(s) ',
 
 	'LOGGED_IN_AS'			=> 'Vous êtes connecté(e) en tant que :',
@@ -391,21 +391,21 @@ $lang = array_merge($lang, array(
 	'VIEW_INACTIVE_USERS'		=> 'Consulter la liste des utilisateurs inactifs',
 
 	'WELCOME_PHPBB'			=> 'Bienvenue sur phpBB',
-	'WRITABLE_CONFIG'		=> 'Votre fichier de configuration (config.php) est actuellement inscriptible par tout le monde. Nous vous encourageons fortement à modifier vos permissions en 640 (<a href="http://fr.wikipedia.org/wiki/Chmod" rel="external">chmod</a> 640 config.php) ou, si cela n’est pas possible, au moins en 644.',
+	'WRITABLE_CONFIG'		=> 'Votre fichier de configuration (config.php) est actuellement inscriptible par tout le monde. Nous vous encourageons fortement à modifier vos permissions en 640 (<a href="http://fr.wikipedia.org/wiki/Chmod" rel="external">chmod</a> 640 config.php) ou, si cela n’est pas possible, en 644.',
 ));
 
 // Inactive Users
 $lang = array_merge($lang, array(
 	'INACTIVE_DATE'					=> 'Date d’inactivité',
-	'INACTIVE_REASON'				=> 'Raison',
+	'INACTIVE_REASON'				=> 'Raison ',
 	'INACTIVE_REASON_MANUAL'		=> 'Le compte a été désactivé par un administrateur',
 	'INACTIVE_REASON_PROFILE'		=> 'Les informations du profil ont été modifiées',
 	'INACTIVE_REASON_REGISTER'		=> 'Le compte a été inscrit récemment',
 	'INACTIVE_REASON_REMIND'		=> 'Le compte doit être réactivé',
 	'INACTIVE_REASON_UNKNOWN'		=> 'Inconnue',
 	'INACTIVE_USERS'				=> 'Utilisateurs inactifs',
-	'INACTIVE_USERS_EXPLAIN'		=> 'Ceci est la liste des utilisateurs inscrits mais dont le compte est actuellement inactif. Si vous le souhaitez, vous pouvez activer, supprimer ou envoyer un rappel (par courriel) à ces utilisateurs.',
-	'INACTIVE_USERS_EXPLAIN_INDEX'	=> 'Ceci est la liste des dix derniers utilisateurs inscrits mais dont le compte est actuellement inactif. Si vous le souhaitez, vous pouvez consulter la liste complète de ces membres par l’intermédiaire du menu approprié ou en cliquant sur le lien ci-dessous d’où vous pourrez activer, supprimer ou envoyer un rappel (par courriel) à ces utilisateurs.',
+	'INACTIVE_USERS_EXPLAIN'		=> 'Ceci est la liste des utilisateurs inscrits dont le compte est actuellement inactif. Si vous le souhaitez, vous pouvez activer, supprimer ou rappeler (en envoyant un courriel) ces utilisateurs.',
+	'INACTIVE_USERS_EXPLAIN_INDEX'	=> 'Ceci est la liste des dix derniers utilisateurs inscrits dont le compte est actuellement inactif. Les comptes peuvent être inactifs lorsqu’une activation est exigée dans les réglages des inscriptions mais que certains comptes d’utilisateurs n’ont pas encore été activés. Les comptes d’utilisateurs désactivés sont également affichés dans cette liste. Si vous le souhaitez, vous pouvez consulter la liste complète de ces membres par l’intermédiaire du menu approprié ou en cliquant sur le lien ci-dessous d’où vous pourrez activer, supprimer ou rappeler (en envoyant un courriel) ces utilisateurs.',
 
 	'NO_INACTIVE_USERS'	=> 'Aucun utilisateur inactif',
 
