@@ -6,7 +6,7 @@
 * @package language
 * @version $Id$
 * @copyright (c) 2005 phpBB Group, (c) 2005 phpBB.fr
-* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License 2.0
+* @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
 */
 
@@ -40,9 +40,9 @@ $lang = array_merge($lang, array(
 	'ADD_USERS'						=> 'Ajouter des utilisateurs',
 	'ADD_USERS_EXPLAIN'				=> 'Vous pouvez ajouter ici de nouveaux utilisateurs à un groupe d’utilisateurs. Vous pouvez également spécifier un groupe d’utilisateurs par défaut aux utilisateurs que vous avez sélectionnés. De plus, vous pouvez promouvoir certains membres d’un groupe d’utilisateurs comme responsables de ce dernier. Veuillez saisir chaque nom d’utilisateur sur une nouvelle ligne.',
 
-	'COPY_PERMISSIONS'				=> 'Copier les permissions de',
+	'COPY_PERMISSIONS'				=> 'Copier les permissions de ',
 	'COPY_PERMISSIONS_EXPLAIN'		=> 'Une fois que ce groupe d’utilisateurs sera créé, ses permissions seront identiques à celles du groupe d’utilisateurs que vous avez sélectionné ici.',
-	'CREATE_GROUP'					=> 'Créer un nouveau groupe d’utilisateurs',
+	'CREATE_GROUP'					=> 'Créer un nouveau groupe d’utilisateurs ',
 
 	'GROUPS_NO_MEMBERS'				=> 'Ce groupe d’utilisateurs n’a aucun membre',
 	'GROUPS_NO_MODS'				=> 'Ce groupe d’utilisateurs n’a aucun responsable',
@@ -54,8 +54,8 @@ $lang = array_merge($lang, array(
 	'GROUP_CLOSED'					=> 'Fermé',
 	'GROUP_COLOR'					=> 'Couleur du groupe ',
 	'GROUP_COLOR_EXPLAIN'			=> 'La couleur dans laquelle les noms d’utilisateurs des membres apparaîtront. Laissez ce champ vide si vous souhaitez conserver la couleur des membres par défaut.',
-	'GROUP_CONFIRM_ADD_USER'		=> 'Êtes-vous sûr(e) de vouloir ajouter l’utilisateur %1$s à ce groupe d’utilisateurs ?',
-	'GROUP_CONFIRM_ADD_USERS'		=> 'Êtes-vous sûr(e) de vouloir ajouter les utilisateurs %1$s à ce groupe d’utilisateurs ?',
+	'GROUP_CONFIRM_ADD_USER'		=> 'Êtes-vous sûr(e) de vouloir ajouter l’utilisateur %1$s au groupe d’utilisateurs ?',
+	'GROUP_CONFIRM_ADD_USERS'		=> 'Êtes-vous sûr(e) de vouloir ajouter les utilisateurs %1$s au groupe d’utilisateurs ?',
 	'GROUP_CREATED'					=> 'Le groupe d’utilisateurs a été créé.',
 	'GROUP_DEFAULT'					=> 'Définir comme groupe d’utilisateurs par défaut pour les membres',
 	'GROUP_DEFS_UPDATED'			=> 'Le groupe d’utilisateurs a été réglé comme groupe d’utilisateurs par défaut pour tous les membres sélectionnés.',
@@ -126,7 +126,7 @@ $lang = array_merge($lang, array(
 	'USER_DEF_GROUPS_EXPLAIN'		=> 'Les groupes définis par un administrateur sont des groupes d’utilisateurs créés par vous-même ou par un autre administrateur du forum. Vous pouvez gérer leurs adhésions, éditer leurs propriétés ou encore les supprimer.',
 	'USER_GROUP_DEFAULT'			=> 'Définir comme groupe par défaut ',
 	'USER_GROUP_DEFAULT_EXPLAIN'	=> 'Si cette option est activée, ce groupe d’utilisateurs sera considéré comme le groupe d’utilisateurs par défaut de tous les utilisateurs.',
-	'USER_GROUP_LEADER'				=> 'Promouvoir comme responsable du groupe',
+	'USER_GROUP_LEADER'				=> 'Promouvoir en responsable du groupe ',
 ));
 
 ?>
\ No newline at end of file
