@@ -6,7 +6,7 @@
 * @package language
 * @version $Id$
 * @copyright (c) 2005 phpBB Group, (c) 2005 phpBB.fr
-* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License 2.0
+* @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
 */
 
@@ -47,12 +47,12 @@ $lang = array_merge($lang, array(
 	'HELP_FILES'				=> 'Fichiers d’aide',
 
 	'INSTALLED_LANGUAGE_PACKS'	=> 'Archive(s) de langue installée(s)',
-	'INVALID_LANGUAGE_PACK'		=> 'L’archive de langue que vous avez sélectionnée semble incorrecte. Veuillez la vérifier et la transférer de nouveau, si cela est nécessaire.',
+	'INVALID_LANGUAGE_PACK'		=> 'L’archive de langue que vous avez sélectionnée semble incorrecte. Veuillez vérifier l’archive de langue et la transférer de nouveau si nécessaire.',
 	'INVALID_UPLOAD_METHOD'		=> 'La méthode de transfert que vous avez sélectionnée est incorrecte. Veuillez sélectionner une nouvelle méthode.',
 
 	'LANGUAGE_DETAILS_UPDATED'			=> 'Les informations sur la langue ont été mises à jour.',
 	'LANGUAGE_ENTRIES'					=> 'Clés de langue',
-	'LANGUAGE_ENTRIES_EXPLAIN'			=> 'Vous pouvez modifier ici les clés de langue afin de les personnaliser ou de les traduire si elles ne le sont pas.<br /><strong>Note :</strong> une fois que vous avez modifié un fichier de langue, ce dernier sera stocké dans un répertoire séparé afin que vous puissiez le télécharger. Les modifications ne seront visibles aux utilisateurs qu’après avoir remplacé le fichier de langue original par le fichier de langue modifié en transférant celui-ci sur votre espace internet.',
+	'LANGUAGE_ENTRIES_EXPLAIN'			=> 'Vous pouvez modifier ici les clés de langue existantes ou traduire celles qui ne le sont pas.<br /><strong>Note :</strong> une fois que vous avez modifié un fichier de langue, ce dernier sera stocké dans un répertoire séparé afin que vous puissiez le télécharger. Les modifications ne seront visibles aux utilisateurs qu’après avoir écrasé les fichiers de langue déjà présents sur votre espace internet.',
 	'LANGUAGE_FILES'					=> 'Fichiers de langue',
 	'LANGUAGE_KEY'						=> 'Clé de langue',
 	'LANGUAGE_PACK_ALREADY_INSTALLED'	=> 'Cette archive de langue est déjà installée.',
@@ -77,7 +77,7 @@ $lang = array_merge($lang, array(
 
 	'NO_FILE_SELECTED'				=> 'Vous n’avez spécifié aucun fichier de langue.',
 	'NO_LANG_ID'					=> 'Vous n’avez spécifié aucune archive de langue.',
-	'NO_REMOVE_DEFAULT_LANG'		=> 'Vous ne pouvez pas supprimer l’archive de langue par défaut.<br />Si vous souhaitez supprimer cette archive de langue, veuillez avant tout modifier la langue par défaut de votre forum.',
+	'NO_REMOVE_DEFAULT_LANG'		=> 'Vous ne pouvez pas supprimer l’archive de langue par défaut.<br />Si vous souhaitez supprimer cette archive de langue, veuillez tout d’abord modifier la langue par défaut de votre forum.',
 	'NO_UNINSTALLED_LANGUAGE_PACKS'	=> 'Aucune archive de langue n’est non installée',
 
 	'REMOVE_FROM_STORAGE_FOLDER'		=> 'Supprimer du répertoire de stockage',
@@ -86,14 +86,14 @@ $lang = array_merge($lang, array(
 	'SUBMIT_AND_DOWNLOAD'		=> 'Envoyer et télécharger le fichier',
 	'SUBMIT_AND_UPLOAD'			=> 'Envoyer et transférer le fichier',
 
-	'THOSE_MISSING_LANG_FILES'			=> 'Les fichiers de langue suivants sont absents du répertoire de langue %s',
-	'THOSE_MISSING_LANG_VARIABLES'		=> 'Les variables de langue suivantes sont absentes de l’archive de langue <strong>%s</strong>.',
+	'THOSE_MISSING_LANG_FILES'			=> 'Les fichiers de langue suivants sont manquants du répertoire de langue %s',
+	'THOSE_MISSING_LANG_VARIABLES'		=> 'Les variables de langue suivantes sont manquantes de l’archive de langue <strong>%s</strong>.',
 
 	'UNINSTALLED_LANGUAGE_PACKS'	=> 'Archives de langue non installées',
 
 	'UNABLE_TO_WRITE_FILE'		=> 'Le fichier n’a pas pu être écrit sur %s.',
 	'UPLOAD_COMPLETED'			=> 'Le transfert a été effectué.',
-	'UPLOAD_FAILED'				=> 'Le transfert a échoué pour une raison inconnue. Vous devriez vérifier la structure du fichier que vous essayez de transférer et le remplacer si nécessaire.',
+	'UPLOAD_FAILED'				=> 'Le transfert a échoué pour une raison inconnue. Vous devriez essayer de remplacer manuellement le fichier en cause si nécessaire.',
 	'UPLOAD_METHOD'				=> 'Méthode de transfert ',
 	'UPLOAD_SETTINGS'			=> 'Réglages du transfert',
 
