@@ -5,7 +5,7 @@
 * @package language
 * @version $Id$
 * @copyright (c) 2005 phpBB Group, (c) 2005 phpBB.fr
-* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License 2.0
+* @license http://opensource.org/licenses/gpl-license.php GNU Public License
 */
 
 /**
@@ -106,7 +106,7 @@ $lang = array_merge($lang, array(
 
 	'acl_u_attach'		=> array('lang' => 'Peut insérer des pièces jointes', 'cat' => 'post'),
 	'acl_u_download'	=> array('lang' => 'Peut télécharger les pièces jointes', 'cat' => 'post'),
-	'acl_u_savedrafts'	=> array('lang' => 'Peut sauvegarder les brouillons', 'cat' => 'post'),
+	'acl_u_savedrafts'	=> array('lang' => 'Peut sauvegarder des brouillons', 'cat' => 'post'),
 	'acl_u_chgcensors'	=> array('lang' => 'Peut désactiver la censure de mots', 'cat' => 'post'),
 	'acl_u_sig'			=> array('lang' => 'Peut insérer une signature', 'cat' => 'post'),
 
