@@ -6,7 +6,7 @@
 * @package language
 * @version $Id$
 * @copyright (c) 2005 phpBB Group, (c) 2005 phpBB.fr
-* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License 2.0
+* @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
 */
 
@@ -37,7 +37,7 @@ if (empty($lang) || !is_array($lang))
 
 $lang = array_merge($lang, array(
 	'ACP_IMAGESETS_EXPLAIN'	=> 'Les ensembles d’images comprennent toutes les images de boutons, de forums, de dossiers, etc. Ils comprennent également d’autres images qui ne sont pas spécifiques au style utilisé sur le forum. Vous pouvez éditer, exporter ou supprimer ici les ensembles d’images et en importer ou en activer de nouveaux.',
-	'ACP_STYLES_EXPLAIN'	=> 'Vous pouvez gérer ici les styles disponibles sur votre forum. Un style comprend un ensemble de templates, de thèmes et d’images. Vous pouvez modifier les styles existants et supprimer, désactiver, réactiver, créer ou en importer de nouveaux. Vous pouvez également voir à quoi va ressembler un style en utilisant la fonction de prévisualisation. Le style actuellement par défaut est noté par la présence d’un astérisque (*). Vous pouvez également retrouver le compteur du nombre total d’utilisateurs de chaque style.',
+	'ACP_STYLES_EXPLAIN'	=> 'Vous pouvez gérer ici les styles disponibles sur votre forum. Un style comprend un ensemble de templates, de thèmes et d’images. Vous pouvez modifier les styles existants et supprimer, désactiver, réactiver, créer ou en importer de nouveaux. Vous pouvez également voir à quoi va ressembler un style en utilisant la fonction de prévisualisation. Le style actuellement par défaut est noté par la présence d’un astérisque (*). Vous pouvez aussi retrouver le compteur du nombre total d’utilisateurs de chaque style mais il est à noter que l’écrasement du style des utilisateurs ne sera pas répercuté dans cette comptabilisation.',
 	'ACP_TEMPLATES_EXPLAIN'	=> 'Un ensemble de templates comprend toutes les balises utilisées afin de générer l’aspect de votre forum. Vous pouvez éditer, supprimer, exporter, importer et prévisualiser ici ces ensembles. Vous pouvez également modifier le code des templates utilisés afin de générer du BBCode.',
 	'ACP_THEMES_EXPLAIN'	=> 'Vous pouvez créer, installer, éditer, supprimer et exporter ici des thèmes. Un thème est une combinaison de couleurs et d’images appliquée à vos templates afin de définir l’aspect basique de votre forum. La gamme des options disponibles dépend de la configuration de votre serveur et de l’installation de phpBB, veuillez consulter le manuel pour plus d’informations. Veuillez noter qu’en créant de nouveaux thèmes, l’utilisation d’un thème existant basique est optionnelle.',
 	'ADD_IMAGESET'			=> 'Créer un ensemble d’images',
@@ -48,7 +48,7 @@ $lang = array_merge($lang, array(
 	'ADD_TEMPLATE_EXPLAIN'	=> 'Vous pouvez ajouter ici un nouveau template. Des options additionnelles peuvent être présentes, selon la configuration de votre serveur et les permissions assignées aux fichiers. Par exemple, vous pourrez baser ce template sur un template qui existe déjà. Vous pourrez également envoyer ou importer un ensemble de templates depuis le répertoire de stockage.',
 	'ADD_THEME'				=> 'Créer un thème',
 	'ADD_THEME_EXPLAIN'		=> 'Vous pouvez ajouter ici un nouveau thème. Des options additionnelles peuvent être présentes, selon la configuration de votre serveur et les permissions assignées aux fichiers. Par exemple, vous pourrez baser ce thème sur un thème qui existe déjà. Vous pourrez également envoyer ou importer un ensemble de thèmes depuis le répertoire de stockage.',
-	'ARCHIVE_FORMAT'		=> 'Format de l’archive ',
+	'ARCHIVE_FORMAT'		=> 'Format de l’archive',
 	'AUTOMATIC_EXPLAIN'		=> 'Laissez vide afin de tenter une détection automatique.',
 
 	'BACKGROUND'			=> 'Fond',
@@ -59,7 +59,7 @@ $lang = array_merge($lang, array(
 
 	'CACHE'							=> 'Cache',
 	'CACHE_CACHED'					=> 'Mis en cache',
-	'CACHE_FILENAME'				=> 'Fichier template ',
+	'CACHE_FILENAME'				=> 'Fichier template',
 	'CACHE_FILESIZE'				=> 'Taille du fichier',
 	'CACHE_MODIFIED'				=> 'Modifié',
 	'CONFIRM_IMAGESET_REFRESH'		=> 'Êtes-vous sûr(e) de vouloir rafraîchir toutes les données des ensembles d’images ? Cela écrasera toutes les modifications réalisées à partir de l’éditeur des ensembles d’images.',
@@ -111,15 +111,15 @@ $lang = array_merge($lang, array(
 	'FONT_COLOUR'			=> 'Couleur de la police de caractères',
 	'FONT_FACE'				=> 'Police',
 	'FONT_FACE_EXPLAIN'		=> 'Vous pouvez spécifier plusieurs polices de caractères en les séparant par une virgule. Si un utilisateur n’a pas la première police de caractères installée sur son ordinateur, la suivante sera alors sélectionnée.',
-	'FONT_SIZE'				=> 'Taille de la police de caractères',
+	'FONT_SIZE'				=> 'Taille de la police de caractères ',
 
 	'GLOBAL_IMAGES'			=> 'Globales',
 
 	'HIDE_CSS'				=> 'Masquer le CSS brut',
 
-	'IMAGE_WIDTH'				=> 'Largeur de l’image ',
-	'IMAGE_HEIGHT'				=> 'Hauteur de l’image ',
-	'IMAGE'						=> 'Image ',
+	'IMAGE_WIDTH'				=> 'Largeur de l’image',
+	'IMAGE_HEIGHT'				=> 'Hauteur de l’image',
+	'IMAGE'						=> 'Image',
 	'IMAGE_NAME'				=> 'Nom de l’image',
 	'IMAGE_PARAMETER'			=> 'Paramètre',
 	'IMAGE_VALUE'				=> 'Valeur',
@@ -138,7 +138,7 @@ $lang = array_merge($lang, array(
 	'IMAGESET_EXPORT'			=> 'Exporter un ensemble d’images',
 	'IMAGESET_EXPORT_EXPLAIN'	=> 'Vous pouvez exporter ici un ensemble d’images sous forme de fichier compressé. Ce dernier contiendra toutes les données nécessaires afin d’installer l’ensemble d’images sur un autre forum. Vous pouvez soit télécharger le fichier directement, soit le placer dans votre dossier de stockage afin de le télécharger ultérieurement par FTP.',
 	'IMAGESET_EXPORTED'			=> 'L’ensemble d’images a été exporté et stocké dans %s.',
-	'IMAGESET_NAME'				=> 'Nom de l’ensemble d’images ',
+	'IMAGESET_NAME'				=> 'Nom de l’ensemble d’images',
 	'IMAGESET_REFRESHED'		=> 'L’ensemble d’images a été rafraîchi.',
 	'IMAGESET_UPDATED'			=> 'L’ensemble d’images a été mis à jour.',
 	'ITALIC'					=> 'Italique',
@@ -267,11 +267,12 @@ $lang = array_merge($lang, array(
 	'IMG_USER_ICON9'		=> 'Image 9 définie par l’utilisateur',
 	'IMG_USER_ICON10'		=> 'Image 10 définie par l’utilisateur',
 
-	'INCLUDE_DIMENSIONS'		=> 'Inclure les dimensions ',
+	'INACTIVE_STYLES'			=> 'Styles inactifs',
+	'INCLUDE_DIMENSIONS'		=> 'Inclure les dimensions',
 	'INCLUDE_IMAGESET'			=> 'Inclure l’ensemble d’images',
 	'INCLUDE_TEMPLATE'			=> 'Inclure le template',
 	'INCLUDE_THEME'				=> 'Inclure le thème',
-	'INHERITING_FROM'         => 'Hérite de',
+	'INHERITING_FROM'         => 'Hérite de ',
 	'INSTALL_IMAGESET'			=> 'Installer un ensemble d’images',
 	'INSTALL_IMAGESET_EXPLAIN'	=> 'Vous pouvez installer ici un ensemble d’images. Si vous le souhaitez, vous pouvez éditer certaines informations ou utiliser les valeurs par défaut lors de l’installation.',
 	'INSTALL_STYLE'				=> 'Installer un style',
@@ -297,7 +298,7 @@ $lang = array_merge($lang, array(
 	'NO_IMAGESET'				=> 'Aucun ensemble d’images n’a été trouvé dans le système de fichiers.',
 	'NO_IMAGE'					=> 'Aucune image',
 	'NO_IMAGE_ERROR'			=> 'Aucune image n’a été trouvée dans le système de fichiers.',
-	'NO_STYLE'					=> 'Aucune style n’a été trouvé dans le système de fichiers.',
+	'NO_STYLE'					=> 'Aucun style n’a été trouvé dans le système de fichiers.',
 	'NO_TEMPLATE'				=> 'Aucun ensemble de templates n’a été trouvé dans le système de fichiers.',
 	'NO_THEME'					=> 'Aucun thème n’a été trouvé dans le système de fichiers.',
 	'NO_UNINSTALLED_IMAGESET'	=> 'Aucun ensemble d’images désinstallé n’a été détecté.',
@@ -333,16 +334,16 @@ $lang = array_merge($lang, array(
 	'SELECT_IMAGE'				=> 'Sélectionner l’image',
 	'SELECT_TEMPLATE'			=> 'Sélectionner le fichier template',
 	'SELECT_THEME'				=> 'Sélectionner le fichier thème',
-	'SELECTED_IMAGE'			=> 'Image sélectionnée ',
+	'SELECTED_IMAGE'			=> 'Image sélectionnée',
 	'SELECTED_IMAGESET'			=> 'Ensemble d’images sélectionné',
 	'SELECTED_TEMPLATE'			=> 'Template sélectionné',
-	'SELECTED_TEMPLATE_FILE'	=> 'Fichier template sélectionné ',
+	'SELECTED_TEMPLATE_FILE'	=> 'Fichier template sélectionné',
 	'SELECTED_THEME'			=> 'Thème sélectionné',
 	'SELECTED_THEME_FILE'		=> 'Fichier thème sélectionné',
 	'STORE_DATABASE'			=> 'Base de données',
 	'STORE_FILESYSTEM'			=> 'Système de fichiers',
 	'STYLE_ACTIVATE'			=> 'Activer',
-	'STYLE_ACTIVE'				=> 'Activer ',
+	'STYLE_ACTIVE'				=> 'Actif ',
 	'STYLE_ADDED'				=> 'Le style a été ajouté.',
 	'STYLE_DEACTIVATE'			=> 'Désactiver',
 	'STYLE_DEFAULT'				=> 'En faire le style par défaut ',
@@ -360,10 +361,10 @@ $lang = array_merge($lang, array(
 	'STYLE_EXPORT'				=> 'Exporter un style',
 	'STYLE_EXPORT_EXPLAIN'		=> 'Vous pouvez exporter ici un style sous forme de fichier compressé. Un style ne devra pas contenir tous les éléments, mais il doit en contenir au moins un. Par exemple, si vous créez un nouveau thème et un ensemble d’images pour un template fréquemment utilisé, vous pourriez simplement exporter le thème et l’ensemble d’images, en omettant le template. Vous pouvez soit télécharger le dossier directement, soit le placer dans votre répertoire de stockage afin de le télécharger ultérieurement par FTP.',
 	'STYLE_EXPORTED'			=> 'Le style a été exporté et stocké dans %s.',
-	'STYLE_IMAGESET'			=> 'Ensemble d’images ',
+	'STYLE_IMAGESET'			=> 'Ensemble d’images',
 	'STYLE_NAME'				=> 'Nom du style ',
-	'STYLE_TEMPLATE'			=> 'Template ',
-	'STYLE_THEME'				=> 'Thème ',
+	'STYLE_TEMPLATE'			=> 'Template',
+	'STYLE_THEME'				=> 'Thème',
 	'STYLE_USED_BY'				=> 'Utilisé par (en incluant les robots)',
 
 	'TEMPLATE_ADDED'			=> 'L’ensemble de templates a été ajouté au système de fichiers.',
@@ -377,7 +378,7 @@ $lang = array_merge($lang, array(
 	'TEMPLATE_DELETED_FS'		=> 'L’ensemble de templates a été supprimé de la base données mais certains fichiers ont été conservés dans le système de fichiers.',
 	'TEMPLATE_DETAILS_UPDATED'	=> 'Les informations concernant l’ensemble de templates ont été mises à jour.',
 	'TEMPLATE_EDITOR'			=> 'Éditeur de templates en HTML brut',
-	'TEMPLATE_EDITOR_HEIGHT'	=> 'Taille de l’éditeur de templates ',
+	'TEMPLATE_EDITOR_HEIGHT'	=> 'Taille de l’éditeur de templates',
 	'TEMPLATE_ERR_ARCHIVE'		=> 'Veuillez sélectionner une méthode de compression.',
 	'TEMPLATE_ERR_CACHE_READ'	=> 'Le répertoire de cache utilisé afin de stocker les versions des fichiers de templates mis en cache ne peut pas être lu.',
 	'TEMPLATE_ERR_COPY_LONG'	=> 'Le copyright ne doit pas dépasser 60 caractères.',
@@ -393,9 +394,9 @@ $lang = array_merge($lang, array(
 	'TEMPLATE_FILE'				=> 'Fichier template',
 	'TEMPLATE_FILE_UPDATED'		=> 'Le fichier template a été mis à jour.',
 	'TEMPLATE_INHERITS'         => 'Ces ensembles de templates héritent de %s et ne peuvent donc pas avoir de réglages de stockage différents à ceux du super template.',
-	'TEMPLATE_LOCATION'			=> 'Stocker les templates dans ',
+	'TEMPLATE_LOCATION'			=> 'Stocker les templates dans',
 	'TEMPLATE_LOCATION_EXPLAIN'	=> 'Les images sont toujours stockées dans le système de fichiers.',
-	'TEMPLATE_NAME'				=> 'Nom du template ',
+	'TEMPLATE_NAME'				=> 'Nom du template',
 	'TEMPLATE_FILE_NOT_WRITABLE'=> 'Impossible d’écrire sur le fichier template %s. Veuillez vérifier les permissions du répertoire et des fichiers.',
 	'TEMPLATE_REFRESHED'		=> 'Le template a été rafraîchi.',
 
@@ -406,7 +407,7 @@ $lang = array_merge($lang, array(
 	'THEME_DELETED_FS'			=> 'Le thème supprimé de la base de données mais quelques fichiers peuvent subsister dans le système de fichiers.',
 	'THEME_DETAILS_UPDATED'		=> 'Les informations du thème ont été mises à jour.',
 	'THEME_EDITOR'				=> 'Éditeur de thèmes',
-	'THEME_EDITOR_HEIGHT'		=> 'Taille de l’éditeur de thèmes ',
+	'THEME_EDITOR_HEIGHT'		=> 'Taille de l’éditeur de thèmes',
 	'THEME_ERR_ARCHIVE'			=> 'Veuillez sélectionner une méthode de compression.',
 	'THEME_ERR_CLASS_CHARS'		=> 'Seuls les lettres, les chiffres, les points, les deux-points, les tirets, les tirets bas et les croisillons sont tolérés dans les noms de classes.',
 	'THEME_ERR_COPY_LONG'		=> 'Le copyright ne doit pas dépasser 60 caractères.',
@@ -420,9 +421,9 @@ $lang = array_merge($lang, array(
 	'THEME_EXPORT'				=> 'Exporter un thème',
 	'THEME_EXPORT_EXPLAIN'		=> 'Vous pouvez exporter ici un thème sous forme de fichier compressé. Ce fichier compressé contiendra toutes les données nécessaires à l’installation du thème sur un autre forum. Vous pouvez soit télécharger le fichier directement, soit le placer dans votre répertoire de stockage afin de le télécharger ultérieurement par FTP.',
 	'THEME_EXPORTED'			=> 'Le thème a été exporté et stocké dans %s.',
-	'THEME_LOCATION'			=> 'Stocker la feuille de style dans ',
+	'THEME_LOCATION'			=> 'Stocker la feuille de style dans',
 	'THEME_LOCATION_EXPLAIN'	=> 'Les images sont toujours stockées dans le système de fichiers.',
-	'THEME_NAME'				=> 'Nom du thème ',
+	'THEME_NAME'				=> 'Nom du thème',
 	'THEME_REFRESHED'			=> 'Le thème a été rafraîchi.',
 	'THEME_UPDATED'				=> 'Le thème a été mis à jour.',
 
