@@ -6,7 +6,7 @@
 * @package language
 * @version $Id$
 * @copyright (c) 2005 phpBB Group, (c) 2005 phpBB.fr
-* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License 2.0
+* @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
 */
 
@@ -40,7 +40,7 @@ if (empty($lang) || !is_array($lang))
 //
 
 $lang = array_merge($lang, array(
-	'TRANSLATION_INFO'	=> 'Traduit par Maël Soucaze et Elglobo &copy; <a href="http://www.phpbb.fr/">phpBB.fr</a>',
+	'TRANSLATION_INFO'	=> '<a href="http://www.phpbb.fr/">Traduction et support en français</a> &bull; <a href="https://www.wistee.fr/hebergement-phpbb.php">Hébergement phpBB</a>',
 	'DIRECTION'			=> 'ltr',
 	'DATE_FORMAT'		=> '|d F Y|',	// 01 January 2007 (with Relative days enabled)
 	'USER_LANG'			=> 'fr',
@@ -58,7 +58,7 @@ $lang = array_merge($lang, array(
 	'ACCOUNT_NOT_ACTIVATED'			=> 'Votre compte n’a pas encore été activé.',
 	'ACP'							=> 'Panneau de contrôle d’administration',
 	'ACTIVE'						=> 'actif',
-	'ACTIVE_ERROR'					=> 'Le nom d’utilisateur que vous avez spécifié est actuellement inactif. Si vous rencontrez des problèmes lors de l’activation de votre compte, veuillez contacter un administrateur du forum.',
+	'ACTIVE_ERROR'					=> 'Le nom d’utilisateur que vous avez spécifié est actuellement inactif. Si vous rencontrez des difficultés lors de l’activation de votre compte, veuillez contacter un administrateur du forum.',
 	'ADMINISTRATOR'					=> 'Administrateur',
 	'ADMINISTRATORS'				=> 'Administrateurs',
 	'AGE'							=> 'Âge ',
@@ -74,9 +74,9 @@ $lang = array_merge($lang, array(
 	'ARE_WATCHING_FORUM'			=> 'Vous êtes à présent abonné(e) à ce forum. Vous recevrez une notification lorsqu’un nouveau sujet sera publié dans ce dernier.',
 	'ARE_WATCHING_TOPIC'			=> 'Vous êtes à présent abonné(e) à ce sujet. Vous recevrez une notification lorsqu’un nouveau message sera publié dans ce dernier.',
 	'ASCENDING'						=> 'Croissant',
-	'ATTACHMENTS'					=> 'Pièces jointes',
+	'ATTACHMENTS'					=> 'Pièces jointes ',
 	'ATTACHED_IMAGE_NOT_IMAGE'		=> 'L’image que vous avez essayé d’insérer est incorrecte.',
-	'AUTHOR'						=> 'Auteur',
+	'AUTHOR'						=> 'Auteur ',
 	'AUTH_NO_PROFILE_CREATED'		=> 'La création du profil utilisateur a échoué.',
 	'AVATAR_DISALLOWED_CONTENT'		=> 'Le transfert a été interrompu car le fichier transféré a été identifié comme un vecteur d’attaque possible.',
 	'AVATAR_DISALLOWED_EXTENSION'	=> 'Ce fichier ne peut pas être affiché car l’extension <strong>%s</strong> n’est pas autorisée.',
@@ -91,7 +91,7 @@ $lang = array_merge($lang, array(
 	'AVATAR_URL_INVALID'			=> 'Le lien que vous avez spécifié est incorrect.',
 	'AVATAR_URL_NOT_FOUND'			=> 'Le fichier que vous avez spécifié est introuvable.',
 	'AVATAR_WRONG_FILESIZE'			=> 'La taille de l’avatar doit être comprise entre 0 et %1d %2s.',
-	'AVATAR_WRONG_SIZE'				=> 'La taille de l’avatar que vous avez envoyé mesure %5$d pixels de large et de %6$d pixels de haut. Cependant, la taille des avatars doit mesurer entre %1$d pixels de large et %2$d pixels de haut, mais ne doit pas dépasser %3$d pixels de large et %4$d pixels de haut.',
+	'AVATAR_WRONG_SIZE'				=> 'La taille de l’avatar que vous avez envoyé mesure %5$d pixel(s) de large et de %6$d pixel(s) de haut. Cependant, la taille des avatars doit mesurer entre %1$d pixel(s) de large et %2$d pixel(s) de haut, mais ne doit pas dépasser %3$d pixel(s) de large et %4$d pixel(s) de haut.',
 
 	'BACK_TO_TOP'			=> 'Haut',
 	'BACK_TO_PREV'			=> 'Retour à la page précédente',
@@ -123,7 +123,7 @@ $lang = array_merge($lang, array(
 	'COLOUR_SWATCH'			=> 'Palette de couleurs',
 	'COMMA_SEPARATOR'		=> ', ',	// Used in pagination of ACP & prosilver, use localised comma if appropriate, eg: Ideographic or Arabic
 	'CONFIRM'				=> 'Confirmer',
-	'CONFIRM_CODE'			=> 'Code de confirmation',
+	'CONFIRM_CODE'			=> 'Code de confirmation ',
 	'CONFIRM_CODE_EXPLAIN'	=> 'Veuillez saisir le code tel qu’il apparaît dans l’image. Toutes les lettres sont insensibles à la casse.',
 	'CONFIRM_CODE_WRONG'	=> 'Le code de confirmation que vous avez saisi est incorrect.',
 	'CONFIRM_OPERATION'		=> 'Êtes-vous sûr(e) de vouloir effectuer cette opération ?',
@@ -133,14 +133,14 @@ $lang = array_merge($lang, array(
 	'COOKIES_DELETED'		=> 'Tous les cookies du forum ont été supprimés.',
 	'CURRENT_TIME'			=> 'Nous sommes actuellement le %s',
 
-	'DAY'					=> 'jour',
+	'DAY'					=> 'jour ',
 	'DAYS'					=> 'jour(s)',
 	'DELETE'				=> 'Supprimer',
 	'DELETE_ALL'			=> 'Tout supprimer',
 	'DELETE_COOKIES'		=> 'Supprimer tous les cookies du forum',
 	'DELETE_MARKED'			=> 'Supprimer la sélection',
-	'DELETE_POST'			=> 'Supprimer le message',
-	'DELIMITER'				=> 'Séparateur',
+	'DELETE_POST'			=> 'Supprimer le message ',
+	'DELIMITER'				=> 'Séparateur ',
 	'DESCENDING'			=> 'Décroissant',
 	'DISABLED'				=> 'Désactivé',
 	'DISPLAY'				=> 'Afficher ',
@@ -164,8 +164,8 @@ $lang = array_merge($lang, array(
 	'EMPTY_SUBJECT'						=> 'Veuillez spécifier le titre du nouveau sujet.',
 	'EMPTY_MESSAGE_SUBJECT'				=> 'Veuillez spécifier le titre du nouveau message privé.',
 	'ENABLED'							=> 'Activé',
-	'ENCLOSURE'							=> 'Pièce jointe',
-	'ENTER_USERNAME'					=> 'Saisissez le nom d’utilisateur',
+	'ENCLOSURE'							=> 'Pièce jointe ',
+	'ENTER_USERNAME'					=> 'Saisissez le nom d’utilisateur ',
 	'ERR_CHANGING_DIRECTORY'			=> 'Impossible de modifier le répertoire.',
 	'ERR_CONNECTING_SERVER'				=> 'Une erreur est survenue lors de la connexion au serveur.',
 	'ERR_JAB_AUTH'						=> 'Une erreur est survenue lors de l’authentification au serveur Jabber.',
@@ -181,17 +181,17 @@ $lang = array_merge($lang, array(
 	'FAQ'					=> 'FAQ',
 	'FAQ_EXPLAIN'			=> 'Foire aux questions',
 	'FILENAME'				=> 'Nom du fichier ',
-	'FILESIZE'				=> 'Taille du fichier ',
-	'FILEDATE'				=> 'Date du fichier ',
+	'FILESIZE'				=> 'Taille du fichier',
+	'FILEDATE'				=> 'Date du fichier',
 	'FILE_COMMENT'			=> 'Description du fichier ',
 	'FILE_NOT_FOUND'		=> 'Le fichier que vous recherchez est introuvable.',
 	'FIND_USERNAME'			=> 'Trouver un membre ',
-	'FOLDER'				=> 'Dossier',
+	'FOLDER'				=> 'Dossier ',
 	'FORGOT_PASS'			=> 'J’ai oublié mon mot de passe',
 	'FORM_INVALID'			=> 'Le formulaire que vous avez envoyé est incorrect. Veuillez essayer de le renvoyer.',
-	'FORUM'					=> 'Forum',
-	'FORUMS'				=> 'Forums',
-	'FORUMS_MARKED'			=> 'Les forums que vous avez sélectionnés ont été marqués comme lus.',
+	'FORUM'					=> 'Forum ',
+	'FORUMS'				=> 'Forums ',
+	'FORUMS_MARKED'			=> 'Les forums ont été marqués comme lus.',
 	'FORUM_CAT'				=> 'Catégorie du forum',
 	'FORUM_INDEX'			=> 'Index du forum',
 	'FORUM_LINK'			=> 'Forum-lien ',
@@ -203,38 +203,38 @@ $lang = array_merge($lang, array(
 	'FSOCK_DISABLED'		=> 'L’opération n’a pas pu s’effectuer car la fonction <var>fsockopen</var> a été désactivée ou le serveur interrogé est introuvable.',
 	'FSOCK_TIMEOUT'			=> 'Le délai de réponse a expiré lors de la lecture du flux réseau.',
 
-	'FTP_FSOCK_HOST'				=> 'Hôte FTP ',
+	'FTP_FSOCK_HOST'				=> 'Hôte FTP',
 	'FTP_FSOCK_HOST_EXPLAIN'		=> 'Le serveur FTP qui est utilisé afin de vous connecter à votre site.',
-	'FTP_FSOCK_PASSWORD'			=> 'Mot de passe FTP ',
+	'FTP_FSOCK_PASSWORD'			=> 'Mot de passe FTP',
 	'FTP_FSOCK_PASSWORD_EXPLAIN'	=> 'Le mot de passe qui est affilié à votre nom d’utilisateur FTP.',
-	'FTP_FSOCK_PORT'				=> 'Port FTP ',
+	'FTP_FSOCK_PORT'				=> 'Port FTP',
 	'FTP_FSOCK_PORT_EXPLAIN'		=> 'Le port qui est utilisé afin de vous connecter à votre serveur.',
-	'FTP_FSOCK_ROOT_PATH'			=> 'Chemin vers phpBB ',
+	'FTP_FSOCK_ROOT_PATH'			=> 'Chemin vers phpBB',
 	'FTP_FSOCK_ROOT_PATH_EXPLAIN'	=> 'Le chemin de la racine vers votre forum phpBB.',
-	'FTP_FSOCK_TIMEOUT'				=> 'Délai d’attente FTP ',
+	'FTP_FSOCK_TIMEOUT'				=> 'Délai d’attente FTP',
 	'FTP_FSOCK_TIMEOUT_EXPLAIN'		=> 'La durée de temps, en secondes, que le système attendra afin d’obtenir une réponse de votre serveur.',
-	'FTP_FSOCK_USERNAME'			=> 'Nom d’utilisateur FTP ',
+	'FTP_FSOCK_USERNAME'			=> 'Nom d’utilisateur FTP',
 	'FTP_FSOCK_USERNAME_EXPLAIN'	=> 'Le nom d’utilisateur qui est utilisé afin de vous connecter à votre serveur.',
 
-	'FTP_HOST'					=> 'Hôte FTP ',
+	'FTP_HOST'					=> 'Hôte FTP',
 	'FTP_HOST_EXPLAIN'			=> 'Le serveur FTP qui est utilisé afin de vous connecter à votre site.',
-	'FTP_PASSWORD'				=> 'Mot de passe FTP ',
+	'FTP_PASSWORD'				=> 'Mot de passe FTP',
 	'FTP_PASSWORD_EXPLAIN'		=> 'Le mot de passe qui est affilié à votre nom d’utilisateur FTP.',
-	'FTP_PORT'					=> 'Port FTP ',
+	'FTP_PORT'					=> 'Port FTP',
 	'FTP_PORT_EXPLAIN'			=> 'Le port qui est utilisé afin de vous connecter à votre serveur.',
-	'FTP_ROOT_PATH'				=> 'Chemin vers phpBB ',
+	'FTP_ROOT_PATH'				=> 'Chemin vers phpBB',
 	'FTP_ROOT_PATH_EXPLAIN'		=> 'Le chemin de la racine vers votre forum phpBB.',
-	'FTP_TIMEOUT'				=> 'Délai d’attente FTP ',
+	'FTP_TIMEOUT'				=> 'Délai d’attente FTP',
 	'FTP_TIMEOUT_EXPLAIN'		=> 'La durée de temps, en secondes, que le système attendra afin d’obtenir une réponse de votre serveur.',
-	'FTP_USERNAME'				=> 'Nom d’utilisateur FTP ',
+	'FTP_USERNAME'				=> 'Nom d’utilisateur FTP',
 	'FTP_USERNAME_EXPLAIN'		=> 'Le nom d’utilisateur qui est utilisé afin de vous connecter à votre serveur.',
 
 	'GENERAL_ERROR'				=> 'Erreur générale',
 	'GB'						=> 'Go',
 	'GIB'						=> 'Gio',
 	'GO'						=> 'Valider',
-	'GOTO_PAGE'					=> 'Aller vers la page',
-	'GROUP'						=> 'Groupe',
+	'GOTO_PAGE'					=> 'Aller vers la page ',
+	'GROUP'						=> 'Groupe ',
 	'GROUPS'					=> 'Groupes',
 	'GROUP_ERR_TYPE'			=> 'Vous avez spécifié un type de groupe incorrect.',
 	'GROUP_ERR_USERNAME'		=> 'Vous n’avez spécifié aucun nom de groupe.',
@@ -276,15 +276,15 @@ $lang = array_merge($lang, array(
 	'IMAGE_FILETYPE_MISMATCH'	=> 'Le type de l’image ne correspond pas. L’extension %1$s était attendue mais l’extension %2$s a été spécifiée.',
 	'IN'						=> 'dans',
 	'INDEX'						=> 'Page d’index',
-	'INFORMATION'				=> 'Information',
+	'INFORMATION'				=> 'Information ',
 	'INTERESTS'					=> 'Centres d’intérêt ',
 	'INVALID_DIGEST_CHALLENGE'	=> 'Le digest challenge est incorrect.',
 	'INVALID_EMAIL_LOG'			=> '<strong>%s</strong> est une adresse de courrier électronique potentiellement incorrecte ?',
-	'IP'						=> 'IP',
+	'IP'						=> 'IP ',
 	'IP_BLACKLISTED'			=> 'Votre adresse IP %1$s a été bloquée car elle apparaît dans la liste noire. Pour plus d’informations, veuillez consulter <a href="%2$s">%2$s</a>.',
 
 	'JABBER'				=> 'Jabber ',
-	'JOINED'				=> 'Inscrit(e) le ',
+	'JOINED'				=> 'Inscription ',
 	'JUMP_PAGE'				=> 'Saisissez le numéro de la page que vous souhaitez atteindre',
 	'JUMP_TO'				=> 'Aller vers ',
 	'JUMP_TO_PAGE'			=> 'Cliquez afin d’aller vers la page…',
@@ -292,9 +292,9 @@ $lang = array_merge($lang, array(
 	'KB'					=> 'Ko',
 	'KIB'					=> 'Kio',
 
-	'LAST_POST'							=> 'Dernier message ',
-	'LAST_UPDATED'						=> 'Dernière mise à jour ',
-	'LAST_VISIT'						=> 'Dernière visite le ',
+	'LAST_POST'							=> 'Dernier message',
+	'LAST_UPDATED'						=> 'Dernière mise à jour',
+	'LAST_VISIT'						=> 'Dernière visite',
 	'LDAP_NO_LDAP_EXTENSION'			=> 'L’extension LDAP est indisponible.',
 	'LDAP_NO_SERVER_CONNECTION'			=> 'Impossible de se connecter au serveur LDAP.',
 	'LDAP_SEARCH_FAILED'				=> 'Une erreur est survenue lors de la recherche du répertoire LDAP.',
@@ -333,15 +333,15 @@ $lang = array_merge($lang, array(
 	'MERGE'					=> 'Fusionner',
 	'MERGE_POSTS'			=> 'Déplacer les messages',
 	'MERGE_TOPIC'			=> 'Fusionner le sujet',
-	'MESSAGE'				=> 'Message',
+	'MESSAGE'				=> 'Message ',
 	'MESSAGES'				=> 'Messages',
 	'MESSAGE_BODY'			=> 'Corps du message ',
 	'MINUTES'				=> 'minute(s)',
 	'MODERATE'				=> 'Modérer',
 	'MODERATOR'				=> 'Modérateur',
-	'MODERATORS'			=> 'Modérateurs',
-	'MONTH'					=> 'Mois',
-	'MOVE'					=> 'Déplacer',
+	'MODERATORS'			=> 'Modérateurs ',
+	'MONTH'					=> 'Mois ',
+	'MOVE'					=> 'Déplacer ',
 	'MSNM'					=> 'MSNM/WLM ',
 
 	'NA'						=> 'N/A',
@@ -421,17 +421,17 @@ $lang = array_merge($lang, array(
 	'OPTIONS'					=> 'Options ',
 
 	'PAGE_OF'				=> 'Page <strong>%1$d</strong> sur <strong>%2$d</strong>',
-	'PASSWORD'				=> 'Mot de passe',
+	'PASSWORD'				=> 'Mot de passe ',
 	'PIXEL'					=> 'px',
 	'PLAY_QUICKTIME_FILE'	=> 'Lire la vidéo QuickTime',
 	'PM'					=> 'MP ',
 	'PM_REPORTED'			=> 'Cliquez ici afin de consulter le rapport',
 	'POSTING_MESSAGE'		=> 'Rédige un message dans %s',
 	'POSTING_PRIVATE_MESSAGE'	=> 'Rédige un message privé',
-	'POST'					=> 'Message',
+	'POST'					=> 'Message ',
 	'POST_ANNOUNCEMENT'		=> 'Annonce',
 	'POST_STICKY'			=> 'Note',
-	'POSTED'				=> 'Publié',
+	'POSTED'				=> 'Publié ',
 	'POSTED_IN_FORUM'		=> 'dans',
 	'POSTED_ON_DATE'		=> 'le',
 	'POSTS'					=> 'Message(s) ',
@@ -441,16 +441,17 @@ $lang = array_merge($lang, array(
 	'POST_DAY'				=> '%.2f message(s) par jour',
 	'POST_DETAILS'			=> 'Informations sur le message',
 	'POST_NEW_TOPIC'		=> 'Publier un nouveau sujet',
-	'POST_PCT'				=> '%.2f%% du nombre total de messages',
-	'POST_PCT_ACTIVE'		=> '%.2f%% du nombre total de messages de l’utilisateur',
-	'POST_PCT_ACTIVE_OWN'	=> '%.2f%% de votre nombre total de messages',
+	'POST_PCT'				=> '%.2f %% du nombre total de messages',
+	'POST_PCT_ACTIVE'		=> '%.2f %% du nombre total de messages de l’utilisateur',
+	'POST_PCT_ACTIVE_OWN'	=> '%.2f %% de votre nombre total de messages',
 	'POST_REPLY'			=> 'Publier une réponse',
 	'POST_REPORTED'			=> 'Cliquez ici afin de consulter le rapport',
-	'POST_SUBJECT'			=> 'Sujet du message',
+	'POST_SUBJECT'			=> 'Sujet du message ',
 	'POST_TIME'				=> 'Date du message',
 	'POST_TOPIC'			=> 'Publier un nouveau sujet',
-	'POST_UNAPPROVED'		=> 'Ce message est en attente d’approbation',
-	'PREVIEW'				=> 'Prévisualiser',
+	'POST_UNAPPROVED'		=> 'Ce message est en attente d’approbation ',
+	'POWERED_BY'			=> 'Propulsé par %s',
+	'PREVIEW'				=> 'Prévisualiser ',
 	'PREVIOUS'				=> 'Précédent',		// Used in pagination
 	'PREVIOUS_STEP'			=> 'Précédent',
 	'PRIVACY'				=> 'Politique de confidentialité',
@@ -459,15 +460,16 @@ $lang = array_merge($lang, array(
 	'PRIVATE_MESSAGING'		=> 'Messagerie privée',
 	'PROFILE'				=> 'Panneau de contrôle de l’utilisateur',
 
+	'RANK'						=> 'Rang ',
 	'READING_FORUM'				=> 'Consulte des sujets dans %s',
 	'READING_GLOBAL_ANNOUNCE'	=> 'Consulte une annonce globale',
 	'READING_LINK'				=> 'Visite le forum-lien %s',
 	'READING_TOPIC'				=> 'Consulte un sujet dans %s',
 	'READ_PROFILE'				=> 'Profil',
-	'REASON'					=> 'Raison',
+	'REASON'					=> 'Raison ',
 	'RECORD_ONLINE_USERS'		=> 'Le nombre maximum d’utilisateurs en ligne simultanément a été de <strong>%1$s</strong> le %2$s',
 	'REDIRECT'					=> 'Redirection',
-	'REDIRECTS'					=> 'Nombre total de redirections',
+	'REDIRECTS'					=> 'Nombre total de redirections ',
 	'REGISTER'					=> 'Inscription',
 	'REGISTERED_USERS'			=> 'Utilisateur(s) inscrit(s) :',
 	'REG_USERS_ONLINE'			=> 'Il y a %d utilisateurs inscrits et ',
@@ -481,7 +483,7 @@ $lang = array_merge($lang, array(
 	'REG_USER_TOTAL_AND'		=> '%d inscrit et ',
 	'REMOVE'					=> 'Supprimer',
 	'REMOVE_INSTALL'			=> 'Veuillez supprimer, déplacer ou renommer le répertoire « install » avant d’utiliser votre forum. Tant que ce répertoire est présent, vous n’aurez accès qu’au panneau de contrôle d’administration.',
-	'REPLIES'					=> 'Réponse(s)',
+	'REPLIES'					=> 'Réponse(s) ',
 	'REPLY_WITH_QUOTE'			=> 'Répondre en citant',
 	'REPLYING_GLOBAL_ANNOUNCE'	=> 'Répond à une annonce globale',
 	'REPLYING_MESSAGE'			=> 'Répond à un message dans %s',
@@ -495,7 +497,7 @@ $lang = array_merge($lang, array(
 	'RETURN_FORUM'				=> '%sRetour au dernier forum visité%s',
 	'RETURN_PAGE'				=> '%sRetour à la page précédente%s',
 	'RETURN_TOPIC'				=> '%sRetour au dernier sujet visité%s',
-	'RETURN_TO'					=> 'Retour vers',
+	'RETURN_TO'					=> 'Retour vers ',
 	'FEED'						=> 'Flux',
 	'FEED_NEWS'					=> 'Nouveautés',
 	'FEED_TOPICS_ACTIVE'		=> 'Sujets actifs',
@@ -524,7 +526,7 @@ $lang = array_merge($lang, array(
 	'SEARCH_KEYWORDS'			=> 'Rechercher par mots-clés ',
 	'SEARCHING_FORUMS'			=> 'Recherche dans les forums',
 	'SEARCH_ACTIVE_TOPICS'		=> 'Consulter les sujets actifs',
-	'SEARCH_FOR'				=> 'Recherche de',
+	'SEARCH_FOR'				=> 'Recherche de ',
 	'SEARCH_FORUM'				=> 'Rechercher dans ce forum…',
 	'SEARCH_NEW'				=> 'Consulter les nouveaux messages',
 	'SEARCH_POSTS_BY'			=> 'Rechercher les messages de',
@@ -536,7 +538,7 @@ $lang = array_merge($lang, array(
 	'SECONDS'					=> 'seconde(s)',
 	'SELECT'					=> 'Sélectionner ',
 	'SELECT_ALL_CODE'			=> 'Tout sélectionner',
-	'SELECT_DESTINATION_FORUM'	=> 'Veuillez sélectionner un forum de destination',
+	'SELECT_DESTINATION_FORUM'	=> 'Veuillez sélectionner un forum de destination ',
 	'SELECT_FORUM'				=> 'Sélectionner un forum ',
 	'SEND_EMAIL'				=> 'Envoyer un courriel',				// Used for submit buttons
 	'SEND_EMAIL_USER'			=> 'Envoyer un courriel à',				// Used as: {L_SEND_EMAIL_USER} {USERNAME} -> E-mail UserX
@@ -561,8 +563,8 @@ $lang = array_merge($lang, array(
 	'START_WATCHING_TOPIC'		=> 'S’abonner au sujet',
 	'STOP_WATCHING_FORUM'		=> 'Se désabonner du forum',
 	'STOP_WATCHING_TOPIC'		=> 'Se désabonner du sujet',
-	'SUBFORUM'					=> 'Sous-forum ',
-	'SUBFORUMS'					=> 'Sous-forums ',
+	'SUBFORUM'					=> 'Sous-forum',
+	'SUBFORUMS'					=> 'Sous-forums',
 	'SUBJECT'					=> 'Sujet ',
 	'SUBMIT'					=> 'Envoyer',
 
@@ -620,7 +622,7 @@ $lang = array_merge($lang, array(
 	'TOO_SMALL_MAX_RECIPIENTS'		=> 'La valeur du réglage <strong>Nombre maximum de destinataires autorisés par message privé</strong> que vous avez saisie est trop faible.',
 
 	'TOPIC'				=> 'Sujet ',
-	'TOPICS'			=> 'Sujet(s)',
+	'TOPICS'			=> 'Sujet(s) ',
 	'TOPICS_UNAPPROVED'	=> 'Au moins un des sujets de ce forum n’a pas été approuvé.',
 	'TOPIC_ICON'		=> 'Icône de sujet ',
 	'TOPIC_LOCKED'		=> 'Ce sujet est verrouillé, vous ne pouvez rien publier ou éditer.',
@@ -631,7 +633,7 @@ $lang = array_merge($lang, array(
 	'TOPIC_UNAPPROVED'	=> 'Ce sujet n’a pas été approuvé',
 	'TOTAL_ATTACHMENTS'	=> 'Pièce(s) jointe(s)',
 	'TOTAL_LOG'			=> '1 historique',
-	'TOTAL_LOGS'		=> '%d historiques',
+	'TOTAL_LOGS'		=> '%d historique(s)',
 	'TOTAL_NO_PM'		=> '0 message privé',
 	'TOTAL_PM'			=> '1 message privé',
 	'TOTAL_PMS'			=> '%d messages privés',
@@ -686,14 +688,14 @@ $lang = array_merge($lang, array(
 	'VIEWING_PRIVATE_MESSAGES'	=> 'Consulte ses messages privés',
 	'VIEWING_REGISTER'			=> 'Inscrit un compte',
 	'VIEWING_UCP'				=> 'Consulte le panneau de contrôle de l’utilisateur',
-	'VIEWS'						=> 'Consultation(s)',
+	'VIEWS'						=> 'Consultation(s) ',
 	'VIEW_BOOKMARKS'			=> 'Consulter les signets',
 	'VIEW_FORUM_LOGS'			=> 'Consulter l’historique',
 	'VIEW_LATEST_POST'			=> 'Consulter le dernier message',
 	'VIEW_NEWEST_POST'			=> 'Consulter le message non lu le plus récent',
 	'VIEW_NOTES'				=> 'Consulter les notes sur l’utilisateur',
-	'VIEW_ONLINE_TIME'			=> 'basé sur les utilisateurs actifs de la dernière minute',
-	'VIEW_ONLINE_TIMES'			=> 'basé sur les utilisateurs actifs des %d dernières minutes',
+	'VIEW_ONLINE_TIME'			=> 'basé sur le nombre d’utilisateurs actifs de la dernière minute',
+	'VIEW_ONLINE_TIMES'			=> 'basé sur le nombre d’utilisateurs actifs des %d dernières minutes',
 	'VIEW_TOPIC'				=> 'Consulter le sujet',
 	'VIEW_TOPIC_ANNOUNCEMENT'	=> 'Annonce : ',
 	'VIEW_TOPIC_GLOBAL'			=> 'Annonce globale : ',
@@ -702,7 +704,7 @@ $lang = array_merge($lang, array(
 	'VIEW_TOPIC_MOVED'			=> 'Déplacé : ',
 	'VIEW_TOPIC_POLL'			=> 'Sondage : ',
 	'VIEW_TOPIC_STICKY'			=> 'Note : ',
-	'VISIT_WEBSITE'				=> 'Visiter le site internet',
+	'VISIT_WEBSITE'				=> 'Visiter le site internet ',
 
 	'WARNINGS'			=> 'Avertissement(s) ',
 	'WARN_USER'			=> 'Avertir l’utilisateur',
@@ -720,13 +722,13 @@ $lang = array_merge($lang, array(
 	'WRONG_DATA_JABBER'			=> 'Le nom du compte Jabber que vous avez spécifié est incorrect.',
 	'WRONG_DATA_LANG'			=> 'La langue que vous avez spécifiée est incorrecte.',
 	'WRONG_DATA_WEBSITE'		=> 'L’adresse du site internet doit être exacte, comportant le protocole. Par exemple, http://www.exemple.com/.',
-	'WROTE'						=> 'a écrit',
+	'WROTE'						=> 'a écrit ',
 
-	'YEAR'				=> 'Année',
+	'YEAR'				=> 'Année ',
 	'YEAR_MONTH_DAY'	=> '(AAAA-MM-JJ)',
 	'YES'				=> 'Oui',
 	'YIM'				=> 'YIM ',
-	'YOU_LAST_VISIT'	=> 'Dernière visite le : %s',
+	'YOU_LAST_VISIT'	=> 'Dernière visite : %s',
 	'YOU_NEW_PM'		=> 'Vous avez un nouveau message privé dans votre boîte de réception.',
 	'YOU_NEW_PMS'		=> 'Vous avez de nouveaux messages privés dans votre boîte de réception.',
 	'YOU_NO_NEW_PM'		=> 'Vous n’avez aucun nouveau message privé dans votre boîte de réception.',
