@@ -6,7 +6,7 @@
 * @package language
 * @version $Id$
 * @copyright (c) 2005 phpBB Group, (c) 2005 phpBB.fr
-* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License 2.0
+* @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
 */
 
@@ -50,7 +50,7 @@ $lang = array_merge($lang, array(
 	'CC_EMAIL'				=> 'S’envoyer une copie de ce courriel.',
 	'CONTACT_USER'			=> 'Contacter',
 
-	'DEST_LANG'				=> 'Langue',
+	'DEST_LANG'				=> 'Langue ',
 	'DEST_LANG_EXPLAIN'		=> 'Sélectionnez une langue appropriée, si elle existe, concernant le destinataire de ce message.',
 
 	'EMAIL_BODY_EXPLAIN'	=> 'Ce message sera envoyé en texte brut, n’y incluez aucun code HTML ou BBCode. L’adresse de retour de ce message correspond à votre adresse de courrier électronique.',
@@ -78,20 +78,20 @@ $lang = array_merge($lang, array(
 	'IM_ICQ'				=> 'Veuillez noter que des utilisateurs ont pu choisir de ne pas vouloir recevoir de messages instantanés non sollicités.',
 	'IM_JABBER'				=> 'Veuillez noter que des utilisateurs ont pu choisir de ne pas vouloir recevoir de messages instantanés non sollicités.',
 	'IM_JABBER_SUBJECT'		=> 'Ceci est un message automatique, merci de ne pas y répondre ! Message de l’utilisateur %1$s le %2$s.',
-	'IM_MESSAGE'			=> 'Votre message',
+	'IM_MESSAGE'			=> 'Votre message ',
 	'IM_MSNM'				=> 'Veuillez noter que vous avez besoin de Windows Messenger afin d’utiliser cette fonctionnalité.',
 	'IM_MSNM_BROWSER'		=> 'Votre navigateur ne supporte pas cette fonctionnalité.',
 	'IM_MSNM_CONNECT'		=> 'MSNM n’est pas connecté.\nVous devez vous connecter à MSNM afin de continuer.',
-	'IM_NAME'				=> 'Votre nom',
+	'IM_NAME'				=> 'Votre nom ',
 	'IM_NO_DATA'			=> 'Il n’y a aucune information de contact appropriée concernant cet utilisateur.',
 	'IM_NO_JABBER'			=> 'La transmission de messages instantanés vers des utilisateurs de Jabber n’est pas supportée sur ce forum. Vous avez besoin d’installer un client Jabber sur votre système afin de contacter le destinataire ci-dessus.',
-	'IM_RECIPIENT'			=> 'Destinataire',
+	'IM_RECIPIENT'			=> 'Destinataire ',
 	'IM_SEND'				=> 'Envoyer un message',
 	'IM_SEND_MESSAGE'		=> 'Envoyer un message',
 	'IM_SENT_JABBER'		=> 'Votre message destiné à %1$s a été envoyé.',
 	'IM_USER'				=> 'Envoyer un message instantané',
 
-	'LAST_ACTIVE'				=> 'Dernière visite le ',
+	'LAST_ACTIVE'				=> 'Dernière visite ',
 	'LESS_THAN'					=> 'Moins que',
 	'LIST_USER'					=> '1 utilisateur',
 	'LIST_USERS'				=> '%d utilisateurs',
@@ -108,16 +108,15 @@ $lang = array_merge($lang, array(
 	'ORDER'					=> 'Ordre',
 	'OTHER'					=> 'Autre',
 
-	'POST_IP'				=> 'Publié depuis le domaine/IP',
+	'POST_IP'				=> 'Publié depuis le domaine/IP ',
 
-	'RANK'					=> 'Rang',
-	'REAL_NAME'				=> 'Nom du destinataire',
-	'RECIPIENT'				=> 'Destinataire',
+	'REAL_NAME'				=> 'Nom du destinataire ',
+	'RECIPIENT'				=> 'Destinataire ',
 	'REMOVE_FOE'			=> 'Retirer un ignoré',
 	'REMOVE_FRIEND'			=> 'Retirer un ami',
 
 	'SELECT_MARKED'			=> 'Sélectionner la sélection',
-	'SELECT_SORT_METHOD'	=> 'Sélectionner la méthode de tri',
+	'SELECT_SORT_METHOD'	=> 'Sélectionner la méthode de tri ',
 	'SEND_AIM_MESSAGE'		=> 'Envoyer un message AIM',
 	'SEND_ICQ_MESSAGE'		=> 'Envoyer un message ICQ',
 	'SEND_IM'				=> 'Messagerie instantanée',
@@ -141,9 +140,9 @@ $lang = array_merge($lang, array(
 	'USER_PRESENCE'			=> 'Présence sur le forum',
 
 	'VIEWING_PROFILE'		=> 'Consulte un profil - %s',
-	'VISITED'				=> 'Dernière visite le ',
+	'VISITED'				=> 'Dernière visite ',
 
-	'WWW'					=> 'Site internet ',
+	'WWW'					=> 'Site internet',
 ));
 
 ?>
\ No newline at end of file
