@@ -6,7 +6,7 @@
 * @package language
 * @version $Id$
 * @copyright (c) 2005 phpBB Group, (c) 2005 phpBB.fr
-* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License 2.0
+* @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
 */
 
@@ -42,6 +42,7 @@ $lang = array_merge($lang, array(
 	'ADD_POLL'					=> 'Création d’un sondage',
 	'ADD_POLL_EXPLAIN'			=> 'Laissez ces champs vides si vous ne souhaitez pas ajouter de sondage à votre sujet.',
 	'ALREADY_DELETED'			=> 'Ce message a déjà été supprimé.',
+	'ATTACH_DISK_FULL'			=> 'Il n’y a pas assez d’espace disque de libre afin de publier cette pièce jointe.',
 	'ATTACH_QUOTA_REACHED'		=> 'La limite du nombre de pièces jointes sur le forum a été atteinte.',
 	'ATTACH_SIG'				=> 'Insérer une signature (modifiable depuis le panneau de contrôle de l’utilisateur)',
 
@@ -69,12 +70,12 @@ $lang = array_merge($lang, array(
 	'CANNOT_EDIT_TIME'			=> 'Vous ne pouvez désormais plus éditer ou supprimer ce message.',
 	'CANNOT_POST_ANNOUNCE'		=> 'Vous n’êtes pas autorisé(e) à publier des annonces.',
 	'CANNOT_POST_STICKY'		=> 'Vous n’êtes pas autorisé(e) à publier des notes.',
-	'CHANGE_TOPIC_TO'			=> 'Modifier le type de sujet en ',
+	'CHANGE_TOPIC_TO'			=> 'Modifier le type de sujet en',
 	'CLOSE_TAGS'				=> 'Fermer les balises',
 	'CURRENT_TOPIC'				=> 'Sujet actuel',
 
 	'DELETE_FILE'				=> 'Supprimer le fichier',
-	'DELETE_MESSAGE'			=> 'Supprimer le message ',
+	'DELETE_MESSAGE'			=> 'Supprimer le message',
 	'DELETE_MESSAGE_CONFIRM'	=> 'Êtes-vous sûr(e) de vouloir supprimer ce message ?',
 	'DELETE_OWN_POSTS'			=> 'Vous n’êtes autorisé(e) à supprimer que vos propres messages.',
 	'DELETE_POST_CONFIRM'		=> 'Êtes-vous sûr(e) de vouloir supprimer ce message ?',
@@ -97,7 +98,7 @@ $lang = array_merge($lang, array(
 	'FLASH_IS_OFF'				=> 'La balise [flash] est <em>désactivée</em>',
 	'FLASH_IS_ON'				=> 'La balise [flash] est <em>activée</em>',
 	'FLOOD_ERROR'				=> 'Vous ne pouvez pas rédiger de message aussitôt après en avoir publié un.',
-	'FONT_COLOR'				=> 'Couleur de la police',
+	'FONT_COLOR'				=> 'Couleur de la police ',
 	'FONT_COLOR_HIDE'			=> 'Masquer la colorisation de la police',
 	'FONT_HUGE'					=> 'Énorme',
 	'FONT_LARGE'				=> 'Grande',
@@ -122,12 +123,12 @@ $lang = array_merge($lang, array(
 	'LOGIN_EXPLAIN_REPLY'		=> 'Vous devez vous connecter afin de pouvoir répondre aux sujets de ce forum.',
 
 	'MAX_FONT_SIZE_EXCEEDED'	=> 'Vous ne devez utiliser que les polices de caractères dont la taille est inférieure à %1$d.',
-	'MAX_FLASH_HEIGHT_EXCEEDED'	=> 'Vos fichiers Flash ne doivent pas dépasser %1$d pixels de haut.',
-	'MAX_FLASH_WIDTH_EXCEEDED'	=> 'Vos fichiers Flash ne doivent pas dépasser %1$d pixels de large.',
-	'MAX_IMG_HEIGHT_EXCEEDED'	=> 'Vos images ne doivent pas dépasser %1$d pixels de haut.',
-	'MAX_IMG_WIDTH_EXCEEDED'	=> 'Vos images ne doivent pas dépasser %1$d pixels de large.',
+	'MAX_FLASH_HEIGHT_EXCEEDED'	=> 'Vos fichiers Flash ne doivent pas dépasser %1$d pixel(s) de haut.',
+	'MAX_FLASH_WIDTH_EXCEEDED'	=> 'Vos fichiers Flash ne doivent pas dépasser %1$d pixel(s) de large.',
+	'MAX_IMG_HEIGHT_EXCEEDED'	=> 'Vos images ne doivent pas dépasser %1$d pixel(s) de haut.',
+	'MAX_IMG_WIDTH_EXCEEDED'	=> 'Vos images ne doivent pas dépasser %1$d pixel(s) de large.',
 
-	'MESSAGE_BODY_EXPLAIN'		=> 'Saisissez votre message ici. Il ne doit pas contenir plus de <strong>%d</strong> caractères.',
+	'MESSAGE_BODY_EXPLAIN'		=> 'Saisissez votre message ici. Il ne doit contenir que <strong>%d</strong> caractère(s) au maximum.',
 	'MESSAGE_DELETED'			=> 'Ce message a été supprimé.',
 	'MORE_SMILIES'				=> 'Accéder à davantage d’émoticônes',
 
@@ -143,14 +144,14 @@ $lang = array_merge($lang, array(
 	'PHP_SIZE_NA'				=> 'La taille de la pièce jointe est trop importante.<br />La taille maximale autorisée, située dans le fichier php.ini, n’a pas pu être déterminée.',
 	'PHP_SIZE_OVERRUN'			=> 'La taille de la pièce jointe est trop importante, la taille maximale autorisée est de %1$d %2$s.<br />Veuillez noter que ce réglage est situé dans le fichier php.ini et qu’il ne peut pas être écrasé.',
 	'PLACE_INLINE'				=> 'Insérer dans la ligne',
-	'POLL_DELETE'				=> 'Supprimer le sondage',
+	'POLL_DELETE'				=> 'Supprimer le sondage ',
 	'POLL_FOR'					=> 'Conserver le sondage pendant ',
 	'POLL_FOR_EXPLAIN'			=> 'Saisissez « 0 » ou laissez vide afin de ne jamais terminer le sondage.',
 	'POLL_MAX_OPTIONS'			=> 'Option(s) par utilisateur ',
 	'POLL_MAX_OPTIONS_EXPLAIN'	=> 'Ceci est le nombre d’options que chaque utilisateur peut sélectionner lors de leur vote.',
 	'POLL_OPTIONS'				=> 'Option(s) du sondage ',
-	'POLL_OPTIONS_EXPLAIN'		=> 'Insérez chaque option sur une nouvelle ligne. Vous pouvez sélectionner jusqu’à <strong>%d</strong> options.',
-	'POLL_OPTIONS_EDIT_EXPLAIN'	=> 'Insérez chaque option sur une nouvelle ligne. Vous pouvez sélectionner jusqu’à <strong>%d</strong> options. Si vous supprimez ou ajoutez une ou plusieurs options, tous les votes ayant été effectués seront réinitialisés.',
+	'POLL_OPTIONS_EXPLAIN'		=> 'Insérez chaque option sur une nouvelle ligne. Vous pouvez sélectionner jusqu’à <strong>%d</strong> option(s).',
+	'POLL_OPTIONS_EDIT_EXPLAIN'	=> 'Insérez chaque option sur une nouvelle ligne. Vous pouvez sélectionner jusqu’à <strong>%d</strong> option(s). Si vous supprimez ou ajoutez une ou plusieurs options, tous les votes ayant été effectués seront réinitialisés.',
 	'POLL_QUESTION'				=> 'Question du sondage ',
 	'POLL_TITLE_TOO_LONG'		=> 'Le titre du sondage ne doit pas dépasser 100 caractères.',
 	'POLL_TITLE_COMP_TOO_LONG'	=> 'La taille du titre de votre sondage est trop importante. Sachez que les BBCodes ou les émoticônes se sont pas pris en compte et qu’ils devraient par conséquent être supprimés.',
@@ -164,7 +165,7 @@ $lang = array_merge($lang, array(
 	'POST_EDITED'				=> 'Ce message a été édité.',
 	'POST_EDITED_MOD'			=> 'Ce message a été édité mais il doit être approuvé par un modérateur afin d’être visible publiquement.',
 	'POST_GLOBAL'				=> 'Annonce globale',
-	'POST_ICON'					=> 'Icône de message ',
+	'POST_ICON'					=> 'Icône de message',
 	'POST_NORMAL'				=> 'Normal',
 	'POST_REVIEW'				=> 'Prévisualisation du message',
 	'POST_REVIEW_EDIT'			=> 'Prévisualisation du message',
@@ -172,10 +173,10 @@ $lang = array_merge($lang, array(
 	'POST_REVIEW_EXPLAIN'		=> 'Au moins un nouveau message a été publié à partir de ce sujet. Si vous le souhaitez, vous pouvez consulter votre message qui apparaîtra en surbrillance.',
 	'POST_STORED'				=> 'Ce message a été publié.',
 	'POST_STORED_MOD'			=> 'Ce message a été envoyé mais il doit être approuvé par un modérateur afin d’être visible publiquement.',
-	'POST_TOPIC_AS'				=> 'Publier le sujet en tant que ',
+	'POST_TOPIC_AS'				=> 'Publier le sujet en tant que',
 	'PROGRESS_BAR'				=> 'Barre de progression',
 
-	'QUOTE_DEPTH_EXCEEDED'		=> 'Vous ne pouvez insérer que %1$d citations imbriquées.',
+	'QUOTE_DEPTH_EXCEEDED'		=> 'Vous ne pouvez insérer que %1$d citation(s) imbriquée(s).',
 
 	'SAVE'						=> 'Sauvegarder',
 	'SAVE_DATE'					=> 'Sauvegardé le',
@@ -184,18 +185,18 @@ $lang = array_merge($lang, array(
 	'SMILIES'					=> 'Émoticônes',
 	'SMILIES_ARE_OFF'			=> 'Les émoticônes sont <em>désactivées</em>',
 	'SMILIES_ARE_ON'			=> 'Les émoticônes sont <em>activées</em>',
-	'STICKY_ANNOUNCE_TIME_LIMIT'=> 'Durée limite de la note/annonce ',
+	'STICKY_ANNOUNCE_TIME_LIMIT'=> 'Durée limite de la note/annonce',
 	'STICK_TOPIC_FOR'			=> 'Durée limite de la note ',
 	'STICK_TOPIC_FOR_EXPLAIN'	=> 'Saisissez « 0 » ou laissez cette case vide afin de ne jamais terminer la note ou l’annonce. Veuillez noter que ce nombre est relatif à la date du message.',
 	'STYLES_TIP'				=> 'Astuce : les mises en forme peuvent rapidement être appliquées en sélectionnant le texte.',
 
 	'TOO_FEW_CHARS'				=> 'Votre message ne contient pas assez de caractères.',
-	'TOO_FEW_CHARS_LIMIT'		=> 'Votre message contient %1$d caractères. Vous devez saisir au moins %2$d caractères.',
+	'TOO_FEW_CHARS_LIMIT'		=> 'Votre message contient %1$d caractère(s). Vous devez saisir au moins %2$d caractères.',
 	'TOO_FEW_POLL_OPTIONS'		=> 'Vous devez saisir au moins deux options afin de créer le sondage.',
 	'TOO_MANY_ATTACHMENTS'		=> 'Impossible d’ajouter une nouvelle pièce jointe, la limite maximale est de %d.',
 	'TOO_MANY_CHARS'			=> 'Votre message contient trop de caractères.',
-	'TOO_MANY_CHARS_POST'		=> 'Votre message contient %1$d caractères. Le nombre maximum de caractères autorisés est de %2$d.',
-	'TOO_MANY_CHARS_SIG'		=> 'Votre signature contient %1$d caractères. Le nombre maximum de caractères autorisés est de %2$d.',
+	'TOO_MANY_CHARS_POST'		=> 'Votre message contient %1$d caractère(s). Le nombre maximum de caractères autorisés est de %2$d.',
+	'TOO_MANY_CHARS_SIG'		=> 'Votre signature contient %1$d caractère(s). Le nombre maximum de caractères autorisés est de %2$d.',
 	'TOO_MANY_POLL_OPTIONS'		=> 'Vous avez essayé de voter pour un trop grand nombre d’options.',
 	'TOO_MANY_SMILIES'			=> 'Votre message contient trop d’émoticônes. Le nombre maximum d’émoticônes autorisées est de %d.',
 	'TOO_MANY_URLS'				=> 'Votre message contient trop de liens. Le nombre maximum de liens autorisés est de %d.',
@@ -219,7 +220,7 @@ $lang = array_merge($lang, array(
 	'VIEW_PRIVATE_MESSAGE'		=> '%sConsulter le message privé que vous avez envoyé%s',
 
 	'WRONG_FILESIZE'			=> 'Le fichier est trop lourd, la taille maximale autorisée est de %1d %2s.',
-	'WRONG_SIZE'				=> 'La taille de l’image doit mesurer moins de %1$d pixels de large et %2$d pixels de haut et plus de %3$d pixels de large et %4$d pixels de haut. L’image que vous avez envoyée mesure %5$d pixels de large et %6$d pixels de haut.',
+	'WRONG_SIZE'				=> 'La taille de l’image doit mesurer moins de %1$d pixel(s) de large et %2$d pixel(s) de haut et plus de %3$d pixel(s) de large et %4$d pixel(s) de haut. L’image que vous avez envoyée mesure %5$d pixel(s) de large et %6$d pixel(s) de haut.',
 ));
 
 ?>
