@@ -6,7 +6,7 @@
 * @package language
 * @version $Id$
 * @copyright (c) 2005 phpBB Group, (c) 2005 phpBB.fr
-* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License 2.0
+* @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
 */
 
@@ -42,12 +42,12 @@ $lang = array_merge($lang, array(
 	'DISPLAY_RESULTS'		=> 'Afficher les résultats sous forme de ',
 
 	'FOUND_SEARCH_MATCH'		=> 'La recherche a retourné %d résultat',
-	'FOUND_SEARCH_MATCHES'		=> 'La recherche a retourné %d résultats',
-	'FOUND_MORE_SEARCH_MATCHES'	=> 'La recherche a retourné plus de %d résultats',
+	'FOUND_SEARCH_MATCHES'		=> 'La recherche a retourné %d résultat(s)',
+	'FOUND_MORE_SEARCH_MATCHES'	=> 'La recherche a retourné plus de %d résultat(s)',
 
 	'GLOBAL'				=> 'Annonce globale',
 
-	'IGNORED_TERMS'			=> 'ignorés',
+	'IGNORED_TERMS'			=> 'ignorés ',
 	'IGNORED_TERMS_EXPLAIN'	=> 'Les mots suivants ont été ignorés lors de votre recherche car ils sont considérés comme trop courants : <strong>%s</strong>.',
 
 	'JUMP_TO_POST'			=> 'Sauter vers le message',
@@ -56,9 +56,9 @@ $lang = array_merge($lang, array(
 	'LOGIN_EXPLAIN_UNREADSEARCH'=> 'Vous devez vous inscrire et vous connecter afin de consulter vos messages non lus.',
 	'LOGIN_EXPLAIN_NEWPOSTS'	=> 'Vous devez vous inscrire et vous connecter afin de consulter les nouveaux messages qui ont été publiés depuis votre dernière visite.',
 
-	'MAX_NUM_SEARCH_KEYWORDS_REFINE'	=> 'Vous avez spécifié un trop grand nombre de mots à rechercher. Veuillez vous limiter à %1$d mots.',
+	'MAX_NUM_SEARCH_KEYWORDS_REFINE'	=> 'Vous avez spécifié un trop grand nombre de mots à rechercher. Veuillez vous limiter à %1$d mot(s).',
 
-	'NO_KEYWORDS'			=> 'Vous devez spécifier au moins un mot afin d’effectuer une recherche. Chaque mot doit être composé d’au moins %d caractères et ne doit pas contenir plus de %d caractères, en excluant les jokers.',
+	'NO_KEYWORDS'			=> 'Vous devez spécifier au moins un mot afin d’effectuer une recherche. Chaque mot doit être composé d’au moins %d caractère(s) et ne doit pas contenir plus de %d caractère(s), en excluant les jokers.',
 	'NO_RECENT_SEARCHES'	=> 'Aucune recherche n’a été effectuée récemment.',
 	'NO_SEARCH'				=> 'Vous n’êtes pas autorisé(e) à utiliser le système de recherche.',
 	'NO_SEARCH_RESULTS'		=> 'Aucun résultat ne correspond au(x) terme(s) que vous avez spécifié(s).',
@@ -75,8 +75,8 @@ $lang = array_merge($lang, array(
 	'RETURN_FIRST'			=> 'Retourner le(s) premier(s) ',
 	'RETURN_TO_SEARCH_ADV'	=> 'Retour à la recherche avancée',
 
-	'SEARCHED_FOR'				=> 'Rechercher les termes utilisés',
-	'SEARCHED_TOPIC'			=> 'Sujet recherché',
+	'SEARCHED_FOR'				=> 'Rechercher les termes utilisés ',
+	'SEARCHED_TOPIC'			=> 'Sujet recherché ',
 	'SEARCH_ALL_TERMS'			=> 'Rechercher tous les termes ou utiliser une question comme élément',
 	'SEARCH_ANY_TERMS'			=> 'Rechercher n’importe quels de ces termes',
 	'SEARCH_AUTHOR'				=> 'Rechercher par auteur ',
@@ -84,7 +84,7 @@ $lang = array_merge($lang, array(
 	'SEARCH_FIRST_POST'			=> 'Le premier message des sujets uniquement',
 	'SEARCH_FORUMS'				=> 'Rechercher dans le(s) forum(s) ',
 	'SEARCH_FORUMS_EXPLAIN'		=> 'Sélectionnez le forum ou les forums dans le(s)quel(s) vous souhaitez effectuer une recherche. Les sous-forums seront automatiquement inclus dans la recherche si vous ne désactivez pas l’option « Rechercher dans les sous-forums » affichée ci-dessous.',
-	'SEARCH_IN_RESULTS'			=> 'Rechercher dans ces résultats',
+	'SEARCH_IN_RESULTS'			=> 'Rechercher dans ces résultats ',
 	'SEARCH_KEYWORDS_EXPLAIN'	=> 'Insérez <strong>+</strong> devant un mot qui doit être trouvé et <strong>-</strong> devant un mot qui doit être ignoré. Insérez une liste de mots séparés entre des barres verticales discontinues <strong>|</strong> si seul un des mots doit être trouvé. Utilisez * comme joker si vous souhaitez effectuer des recherches partielles.',
 	'SEARCH_MSG_ONLY'			=> 'Le contenu des messages uniquement',
 	'SEARCH_OPTIONS'			=> 'Options de la recherche',
@@ -100,7 +100,7 @@ $lang = array_merge($lang, array(
 	'SORT_POST_SUBJECT'			=> 'Sujet du message',
 	'SORT_TIME'					=> 'Heure du message',
 
-	'TOO_FEW_AUTHOR_CHARS'	=> 'Vous devez spécifier au moins %d caractères du nom des auteurs.',
+	'TOO_FEW_AUTHOR_CHARS'	=> 'Vous devez spécifier au moins %d caractère(s) du nom des auteurs.',
 ));
 
 ?>
